CREATE TABLE StatusGeral (
  CodStatusGeral NUMERIC(3) NOT NULL DEFAULT nextval('statusgeral_codstatusgeral'),
  NomeStatusGeral VARCHAR(50) NULL,
  DescStatusGeral VARCHAR NULL,
  PRIMARY KEY(CodStatusGeral)
);

INSERT INTO StatusGeral (CodStatusGeral, NomeStatusGeral, DescStatusGeral) VALUES(DEFAULT,'Ativo','');
INSERT INTO StatusGeral (CodStatusGeral, NomeStatusGeral, DescStatusGeral) VALUES(DEFAULT,'Inativo','');
INSERT INTO StatusGeral (CodStatusGeral, NomeStatusGeral, DescStatusGeral) VALUES(DEFAULT,'Cancelado','');


-- ------------------------------------------------------------
-- Grupos de acesso e definidos para usurios.
-- ------------------------------------------------------------

CREATE TABLE Grupo (
  CodGru NUMERIC(1) NOT NULL DEFAULT nextval('grupo_codgru_seq'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeGru VARCHAR(100) NOT NULL,
  DescGru VARCHAR NULL,
  SenhaExp NUMERIC(3) NOT NULL,
  PRIMARY KEY(CodGru),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO Grupo (CodGru, NomeGru, DescGru, SenhaExp, CodStatusGeral) VALUES(DEFAULT,'Administrador','Permite incluso, alterao e cancelamento de usurios, usurios em grupos, projetos, entidades fsicas, espcies e raas de ave.',999,1);
INSERT INTO Grupo (CodGru, NomeGru, DescGru, SenhaExp, CodStatusGeral) VALUES(DEFAULT,'Operador','Permite incluso, alterao e cancelamento de entidades que permitem incubao, incubao e saque de entidades.',30,1);
INSERT INTO Grupo (CodGru, NomeGru, DescGru, SenhaExp, CodStatusGeral) VALUES(DEFAULT,'Consultor','Permite visualizar status de incubao, gerar relatrios e notificaes de incubaes.',30,1);


-- ------------------------------------------------------------
-- Grau de aplicao da raa de maior influncia.
-- ------------------------------------------------------------

CREATE TABLE GrauSangue (
  CodGS NUMERIC(3) NOT NULL DEFAULT nextval('grausangue_codgs'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeGS VARCHAR(50) NOT NULL,
  DescGS VARCHAR NULL,
  PRIMARY KEY(CodGS),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO GrauSangue (CodGS, NomeGS, DescGS, CodStatusGeral) VALUES(DEFAULT,'Puro','',1); 
INSERT INTO GrauSangue (CodGS, NomeGS, DescGS, CodStatusGeral) VALUES(DEFAULT,'1/2','',1); 
INSERT INTO GrauSangue (CodGS, NomeGS, DescGS, CodStatusGeral) VALUES(DEFAULT,'3/4','',1); 
INSERT INTO GrauSangue (CodGS, NomeGS, DescGS, CodStatusGeral) VALUES(DEFAULT,'7/8','',1);
INSERT INTO GrauSangue (CodGS, NomeGS, DescGS, CodStatusGeral) VALUES(DEFAULT,'Desconhecido','',1); 


-- ------------------------------------------------------------
-- Tipos de momento atual para projetos.
-- ------------------------------------------------------------

CREATE TABLE StatusProjeto (
  CodStatusProj NUMERIC(3) NOT NULL DEFAULT nextval('statusprojeto_codstatusproj'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeStatusProj VARCHAR(50) NOT NULL,
  DescStatusProj VARCHAR NULL,
  PRIMARY KEY(CodStatusProj),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO StatusProjeto (CodStatusProj, NomeStatusProj, DescStatusProj, CodStatusGeral) VALUES(DEFAULT,'Ativo','',1);
INSERT INTO StatusProjeto (CodStatusProj, NomeStatusProj, DescStatusProj, CodStatusGeral) VALUES(DEFAULT,'Inativo','',1);
INSERT INTO StatusProjeto (CodStatusProj, NomeStatusProj, DescStatusProj, CodStatusGeral) VALUES(DEFAULT,'Cancelado','',1);


-- ------------------------------------------------------------
-- Motivos de descarte de posio de entidade.
-- ------------------------------------------------------------

CREATE TABLE MotivoDescarte (
  CodMotDes NUMERIC(3) NOT NULL DEFAULT nextval('motivodescarte_codmotdes'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  MotDes VARCHAR(50) NOT NULL,
  DescMotDes VARCHAR NULL,
  PRIMARY KEY(CodMotDes),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

CREATE TABLE MotivoMorte (
  CodMotMor NUMERIC(3) NOT NULL DEFAULT nextval('motivomorte_codmotmorte'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  MotMor VARCHAR(50) NOT NULL,
  DescMotMor VARCHAR NULL,
  PRIMARY KEY(CodMotMor),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de momento atual para incubaes e nascimentos.
-- ------------------------------------------------------------

CREATE TABLE StatusIncNas (
  CodStatusIN NUMERIC(3) NOT NULL DEFAULT nextval('statusincnas_codstatusin'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeStatusIN VARCHAR(50) NOT NULL,
  DescStatusIN VARCHAR NULL,
  PRIMARY KEY(CodStatusIN),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO StatusIncNas (CodStatusIN, NomeStatusIN, DescStatusIN, CodStatusGeral) VALUES(DEFAULT,'Em Andamento','',1);
INSERT INTO StatusIncNas (CodStatusIN, NomeStatusIN, DescStatusIN, CodStatusGeral) VALUES(DEFAULT,'Concludo','',1);
INSERT INTO StatusIncNas (CodStatusIN, NomeStatusIN, DescStatusIN, CodStatusGeral) VALUES(DEFAULT,'Cancelado','',1);


-- ------------------------------------------------------------
-- Tipos de momento atual para ovos.
-- ------------------------------------------------------------

CREATE TABLE StatusOvo (
  CodStatusOvo NUMERIC(3) NOT NULL DEFAULT nextval('statusovo_codstatusovo'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeStatusOvo VARCHAR(50) NOT NULL,
  DescStatusOvo VARCHAR NULL,
  PRIMARY KEY(CodStatusOvo),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de formato de ovos.
-- ------------------------------------------------------------

CREATE TABLE ForOvo (
  CodForOvo NUMERIC(3) NOT NULL DEFAULT nextval('forovo_codforovo'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeForOvo VARCHAR(50) NOT NULL,
  DescForOvo VARCHAR NULL,
  PRIMARY KEY(CodForOvo),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de medida para unidade.
-- ------------------------------------------------------------

CREATE TABLE TipoUniMed (
  CodTipoMed NUMERIC(8) NOT NULL DEFAULT nextval('tipounimed_codtipomed'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeTipoMed VARCHAR(50) NOT NULL,
  DescTipoMed VARCHAR NULL,
  PRIMARY KEY(CodTipoMed),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de tratamento para pesquisa.
-- ------------------------------------------------------------

CREATE TABLE TipoTratamento (
  CodTipoTrat NUMERIC(8) NOT NULL DEFAULT nextval('tipotratamento_codtipotrat'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeTipoTrat VARCHAR(50) NOT NULL,
  DescTipoTrat VARCHAR NULL,
  PRIMARY KEY(CodTipoTrat),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Bandejas e total de linhas e colunas.
-- ------------------------------------------------------------

CREATE TABLE Bandeja (
  CodBan NUMERIC(8) NOT NULL DEFAULT nextval('bandeja_codban'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  TLinBan NUMERIC(2) NOT NULL,
  TColBan NUMERIC(2) NOT NULL,
  NomeBan VARCHAR(50) NOT NULL,
  PRIMARY KEY(CodBan),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- UFs cadastrados no sistema.
-- ------------------------------------------------------------

CREATE TABLE UF (
  CodUF NUMERIC(3) NOT NULL DEFAULT nextval('uf_coduf'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  SiglaUF CHAR(2) NOT NULL,
  NomeUF VARCHAR(50) NOT NULL,
  PRIMARY KEY(CodUF),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'AC','Acre',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'AL','Alagoas',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'AM','Amazonas',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'AP','Amap',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'BH','Bahia',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'CE','Cear',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'DF','Distrito Federal',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'ES','Esprito Santo',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'GO','Gois',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'MA','Maranho',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'MG','Minas Gerais',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'MS','Mato Grosso do Sul',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'MT','Mato Grosso',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'PA','Par',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'PB','Paraba',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'PE','Pernambuco',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'PI','Piau',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'PR','Paran',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'RJ','Rio de Janeiro',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'RN','Rio Grande do Norte',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'RO','Rondnia',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'RR','Roraima',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'RS','Rio Grande do Sul',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'SC','Santa Catarina',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'SP','So Paulo',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'SE','Sergipe',1); 
INSERT INTO UF (CodUF, SiglaUF, NomeUF, CodStatusGeral) VALUES(DEFAULT,'TO','Tocatins',1); 


-- ------------------------------------------------------------
-- Espcie de ave e suas caractersticas.
-- ------------------------------------------------------------

CREATE TABLE EspecieAve (
  CodEsp NUMERIC(6) NOT NULL DEFAULT nextval('especieave_codesp'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeEsp VARCHAR(50) NOT NULL,
  TempMinInc NUMERIC(6,4) NULL,
  TempMaxInc NUMERIC(6,4) NULL,
  UmiMinInc NUMERIC(6,4) NULL,
  UmiMaxInc NUMERIC(6,4) NULL,
  PerInc NUMERIC(3) NOT NULL,
  PerAviInc NUMERIC(2) NOT NULL,
  TempMinNas NUMERIC(6,4) NULL,
  TempMaxNas NUMERIC(6,4) NULL,
  UmiMinNas NUMERIC(6,4) NULL,
  UmiMaxNas NUMERIC(6,4) NULL,
  PerNas NUMERIC(3) NOT NULL,
  PerAviNas NUMERIC(2) NOT NULL,
  PerRec NUMERIC(3) NOT NULL,
  PRIMARY KEY(CodEsp),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de momento atual para usurios.
-- ------------------------------------------------------------

CREATE TABLE StatusUsuario (
  CodStatusUsu NUMERIC(3) NOT NULL DEFAULT nextval('statususuario_codstatususu_seq'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeStatusUsu VARCHAR(50) NOT NULL,
  DescStatusUsu VARCHAR NULL,
  PRIMARY KEY(CodStatusUsu),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO StatusUsuario (CodStatusUsu, NomeStatusUsu, DescStatusUsu, CodStatusGeral) VALUES(DEFAULT,'Ativo','',1);
INSERT INTO StatusUsuario (CodStatusUsu, NomeStatusUsu, DescStatusUsu, CodStatusGeral) VALUES(DEFAULT,'Inativo','',1);
INSERT INTO StatusUsuario (CodStatusUsu, NomeStatusUsu, DescStatusUsu, CodStatusGeral) VALUES(DEFAULT,'Cancelado','',1);


-- ------------------------------------------------------------
-- Tipo de desinfeco do ovo.
-- ------------------------------------------------------------

CREATE TABLE DesOvo (
  CodDesOvo NUMERIC(3) NOT NULL DEFAULT nextval('desovo_coddesovo'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeDesOvo VARCHAR(50) NOT NULL,
  DescDesOvo VARCHAR NULL,
  PRIMARY KEY(CodDesOvo),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO DesOvo (CodDesOvo, NomeDesOvo, DescDesOvo, CodStatusGeral) VALUES(DEFAULT,'Nenhuma','',1);
INSERT INTO DesOvo (CodDesOvo, NomeDesOvo, DescDesOvo, CodStatusGeral) VALUES(DEFAULT,'Iodo','',1);
INSERT INTO DesOvo (CodDesOvo, NomeDesOvo, DescDesOvo, CodStatusGeral) VALUES(DEFAULT,'Fumigado','',1);
INSERT INTO DesOvo (CodDesOvo, NomeDesOvo, DescDesOvo, CodStatusGeral) VALUES(DEFAULT,'Formol','',1);
INSERT INTO DesOvo (CodDesOvo, NomeDesOvo, DescDesOvo, CodStatusGeral) VALUES(DEFAULT,'Amnia Quaternria','',1);


-- ------------------------------------------------------------
-- Tipos de entidade para projetos.
-- ------------------------------------------------------------

CREATE TABLE TipoEntidade (
  CodTipoEnt NUMERIC(1) NOT NULL DEFAULT nextval('tipoentidade_codtipoent'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  NomeTipoEnt VARCHAR(50) NOT NULL,
  DescTipoEnt VARCHAR NULL,
  TipoEntMin CHAR(1) NOT NULL,
  PRIMARY KEY(CodTipoEnt),
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Ovo','Entidade mnima do projeto permite rastreamento individual por Ovo.','S',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Celula','Entidade mnima do projeto permite rastreamento de ovos por Clula.','S',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Gaiola','Entidade mnima do projeto permite rastreamento de ovos por Gaiola.','S',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Linha','Entidade mnima do projeto permite rastreamento de ovos por Linha.','S',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Bloco','Entidade mnima do projeto permite rastreamento de ovos por Bloco.','S',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Sala','Entidade do projeto permite rastreamento de ovos por Sala.','N',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Andar','Entidade do projeto permite rastreamento de ovos por Andar.','N',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Predio','Entidade do projeto permite rastreamento de ovos por Prdio.','N',1);
INSERT INTO TipoEntidade (CodTipoEnt, NomeTipoEnt, DescTipoEnt, TipoEntMin, CodStatusGeral) VALUES(DEFAULT,'Propriedade','Entidade do projeto permite rastreamento de ovos por Propriedade.','N',1);


-- ------------------------------------------------------------
-- Raas de aves por espcie.
-- ------------------------------------------------------------

CREATE TABLE RacaAve (
  CodRaca NUMERIC(8) NOT NULL DEFAULT nextval('racaave_codraca'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodEsp NUMERIC(6) NOT NULL,
  NomeRaca VARCHAR(100) NOT NULL,
  DescRaca VARCHAR NULL,
  PRIMARY KEY(CodRaca),
  FOREIGN KEY(CodEsp)
    REFERENCES EspecieAve(CodEsp)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Usurios com acesso ao sistema.
-- ------------------------------------------------------------

CREATE TABLE Usuario (
  CodUsu NUMERIC(8) NOT NULL DEFAULT nextval('usuario_codusu')  ,
  CodStatusUsu NUMERIC(3) NOT NULL,
  CodGru NUMERIC(1) NOT NULL,
  MatrUsu CHAR(10) NOT NULL,
  NomeUsu VARCHAR(100) NOT NULL,
  SenCrt VARCHAR NOT NULL,
  DataInc TIMESTAMP NOT NULL DEFAULT CURRENT_DATE,
  TelRes NUMERIC(10) NULL,
  TelCom NUMERIC(10) NULL,
  TelCel NUMERIC(10) NULL,
  Email VARCHAR(50) NOT NULL,
  UltAltSen TIMESTAMP NULL,
  UltLogon TIMESTAMP NULL,
  PRIMARY KEY(CodUsu),
  FOREIGN KEY(CodGru)
    REFERENCES Grupo(CodGru)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusUsu)
    REFERENCES StatusUsuario(CodStatusUsu)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO Usuario (CodUsu, CodStatusUsu, CodGru, MatrUsu, NomeUsu, SenCrt, DataInc, TelRes, TelCom, TelCel, Email, UltAltSen, UltLogon) VALUES(DEFAULT,1,1,'admin','Administrador','admin',CURRENT_TIMESTAMP,NULL,NULL,NULL,'admin@sisinc.com',CURRENT_TIMESTAMP,CURRENT_TIMESTAMP);


-- ------------------------------------------------------------
-- Unidades de medida para valores de repeties.
-- ------------------------------------------------------------

CREATE TABLE UnidadeMedida (
  CodUniMed NUMERIC(10) NOT NULL DEFAULT nextval('unidademedida_codunimed'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodTipoMed NUMERIC(8) NOT NULL,
  NomeUniMed VARCHAR(100) NOT NULL,
  DescUniMed VARCHAR NULL,
  PRIMARY KEY(CodUniMed),
  FOREIGN KEY(CodTipoMed)
    REFERENCES TipoUniMed(CodTipoMed)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Entidades fsicas associadas ao projeto e  incubao.
-- ------------------------------------------------------------

CREATE TABLE Entidade (
  CodEnt NUMERIC(12) NOT NULL DEFAULT nextval('entidade_codent'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodTipoEnt NUMERIC(1) NOT NULL,
  NomeEnt VARCHAR(50) NOT NULL,
  DescEnt VARCHAR NULL,
  PRIMARY KEY(CodEnt),
  FOREIGN KEY(CodTipoEnt)
    REFERENCES TipoEntidade(CodTipoEnt)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tipos de formato de ovos por espcie.
-- ------------------------------------------------------------

CREATE TABLE CorOvo (
  CodCorOvo NUMERIC(3) NOT NULL DEFAULT nextval('corovo_codcorovo'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodEsp NUMERIC(6) NOT NULL,
  NomeCorOvo VARCHAR(50) NOT NULL,
  DescCorOvo VARCHAR NULL,
  PRIMARY KEY(CodCorOvo),
  FOREIGN KEY(CodEsp)
    REFERENCES EspecieAve(CodEsp)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Cidades cadastradas no sistema.
-- ------------------------------------------------------------

CREATE TABLE Cidade (
  CodCid NUMERIC(6) NOT NULL DEFAULT nextval('cidade_codcid'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodUF NUMERIC(3) NOT NULL,
  NomeCid VARCHAR(100) NOT NULL,
  PRIMARY KEY(CodCid),
  FOREIGN KEY(CodUF)
    REFERENCES UF(CodUF)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

INSERT INTO Cidade (CodCid, CodUF, NomeCid, CodStatusGeral) VALUES(DEFAULT,18,'Curitiba',1);


-- ------------------------------------------------------------
-- Tipos de Tratamentos tem Tipos de Unidades de Medidas.
-- ------------------------------------------------------------

CREATE TABLE TipoTratTemUniMed (
  CodTipoTrat NUMERIC(8) NOT NULL,
  CodTipoMed NUMERIC(8) NOT NULL,
  CodStatusGeral NUMERIC(3) NOT NULL,
  PRIMARY KEY(CodTipoTrat, CodTipoMed),
  FOREIGN KEY(CodTipoTrat)
    REFERENCES TipoTratamento(CodTipoTrat)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodTipoMed)
    REFERENCES TipoUniMed(CodTipoMed)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Projetos por espcie de ave definidos no tempo.
-- ------------------------------------------------------------

CREATE TABLE Projeto (
  CodProj NUMERIC(8) NOT NULL DEFAULT nextval('projeto_codproj'),
  CodEsp NUMERIC(6) NOT NULL,
  CodTipoEnt NUMERIC(1) NOT NULL,
  CodStatusProj NUMERIC(3) NOT NULL,
  SiglaProj CHAR(14) NOT NULL,
  NomeProj VARCHAR(100) NOT NULL,
  DataIniProj DATE NOT NULL,
  DataPrevProj DATE NULL,
  DataFimProj DATE NULL,
  DescProj VARCHAR NULL,
  NumInc NUMERIC(3) NULL,
  PRIMARY KEY(CodProj),
  FOREIGN KEY(CodTipoEnt)
    REFERENCES TipoEntidade(CodTipoEnt)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodEsp)
    REFERENCES EspecieAve(CodEsp)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusProj)
    REFERENCES StatusProjeto(CodStatusProj)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Histrico de acessos de usurios.
-- ------------------------------------------------------------

CREATE TABLE HistUsuario (
  CodHistUsu NUMERIC(20) NOT NULL DEFAULT nextval('histusuario_codhistusu_seq'),
  CodUsu NUMERIC(8) NOT NULL,
  SessaoIni TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  SessaoFim TIMESTAMP NULL,
  PRIMARY KEY(CodHistUsu),
  FOREIGN KEY(CodUsu)
    REFERENCES Usuario(CodUsu)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
);

-- ------------------------------------------------------------
-- Propriedade, instituio ou granja de origem.
-- ------------------------------------------------------------

CREATE TABLE Propriedade (
  CodProp NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodCid NUMERIC(6) NOT NULL,
  EndProp VARCHAR NULL,
  PRIMARY KEY(CodProp),
  FOREIGN KEY(CodCid)
    REFERENCES Cidade(CodCid)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodProp)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Prdios disponveis para propriedade.
-- ------------------------------------------------------------

CREATE TABLE Predio (
  CodPre NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodProp NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodPre),
  FOREIGN KEY(CodProp)
    REFERENCES Propriedade(CodProp)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodPre)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Pesquisas pertencentes aos projetos.
-- ------------------------------------------------------------

CREATE TABLE Tratamento (
  CodTrat NUMERIC(10) NOT NULL DEFAULT nextval('tratamento_codtrat'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodProj NUMERIC(8) NOT NULL,
  NomeTrat VARCHAR(255) NOT NULL,
  DescTrat VARCHAR NULL,
  NumRep NUMERIC(3) NULL,
  PRIMARY KEY(CodTrat),
  FOREIGN KEY(CodProj)
    REFERENCES Projeto(CodProj)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Incubao de entidades e suas quantidades de ovos.
-- ------------------------------------------------------------

CREATE TABLE Incubacao (
  CodInc NUMERIC(10) NOT NULL DEFAULT nextval('incubacao_codinc'),
  CodStatusIN NUMERIC(3) NOT NULL,
  CodProj NUMERIC(8) NOT NULL,
  DataIniInc TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  DataPrevInc TIMESTAMP NULL,
  DataFimInc TIMESTAMP NULL,
  NumOvoIniI NUMERIC(3) NOT NULL,
  NumOvoDesI NUMERIC(3) NULL,
  NumOvoTransf NUMERIC(3) NULL,
  ObsStatusInc VARCHAR NULL,
  PRIMARY KEY(CodInc),
  FOREIGN KEY(CodProj)
    REFERENCES Projeto(CodProj)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusIN)
    REFERENCES StatusIncNas(CodStatusIN)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Andares disponveis para prdio.
-- ------------------------------------------------------------

CREATE TABLE Andar (
  CodAnd NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodPre NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodAnd),
  FOREIGN KEY(CodPre)
    REFERENCES Predio(CodPre)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodAnd)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Nascimento de entidades que foram incubadas.
-- ------------------------------------------------------------

CREATE TABLE Nascimento (
  CodNas NUMERIC(10) NOT NULL DEFAULT nextval('nascimento_codnas'),
  CodInc NUMERIC(10) NOT NULL,
  CodStatusIN NUMERIC(3) NOT NULL,
  DataIniINas TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  DataPrevNas TIMESTAMP NULL,
  DataFimNas TIMESTAMP NULL,
  NumOvoIniN NUMERIC(3) NOT NULL,
  NumOvoDesN NUMERIC(3) NULL,
  NumOvoRec NUMERIC(3) NULL,
  ObsStatusNas VARCHAR NULL,
  PRIMARY KEY(CodNas),
  FOREIGN KEY(CodStatusIN)
    REFERENCES StatusIncNas(CodStatusIN)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodInc)
    REFERENCES Incubacao(CodInc)
      ON DELETE NO ACTION
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Tratamentos tem Tipos de Tratamentos.
-- ------------------------------------------------------------

CREATE TABLE TratTemTipoTrat (
  CodTrat NUMERIC(10) NOT NULL,
  CodTipoTrat NUMERIC(8) NOT NULL,
  CodStatusGeral NUMERIC(3) NOT NULL,
  PRIMARY KEY(CodTrat, CodTipoTrat),
  FOREIGN KEY(CodTrat)
    REFERENCES Tratamento(CodTrat)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodTipoTrat)
    REFERENCES TipoTratamento(CodTipoTrat)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Projetos compostos por usurios.
-- ------------------------------------------------------------

CREATE TABLE ProjTemUsu (
  CodProj NUMERIC(8) NOT NULL,
  CodUsu NUMERIC(8) NOT NULL,
  CodStatusGeral NUMERIC(3) NOT NULL,
  Aviso CHAR(1) NOT NULL,
  DataInc DATE NOT NULL,
  DataTer DATE NULL,
  MotAlt VARCHAR NULL,
  PRIMARY KEY(CodProj, CodUsu),
  FOREIGN KEY(CodProj)
    REFERENCES Projeto(CodProj)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodUsu)
    REFERENCES Usuario(CodUsu)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Medies pertencentes ao tratamento.
-- ------------------------------------------------------------

CREATE TABLE Repeticao (
  CodRep NUMERIC(12) NOT NULL DEFAULT nextval('repeticao_codrep'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodEnt NUMERIC(12) NOT NULL,
  CodTrat NUMERIC(10) NOT NULL,
  CodTipoMed NUMERIC(8) NOT NULL,
  DataMedRep TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
  ValMedRep NUMERIC(12,8) NULL,
  CodUniMed NUMERIC(10) NOT NULL,
  PRIMARY KEY(CodRep),
  FOREIGN KEY(CodTrat)
    REFERENCES Tratamento(CodTrat)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodUniMed)
    REFERENCES UnidadeMedida(CodUniMed)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodEnt)
    REFERENCES Entidade(CodEnt)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodTipoMed)
    REFERENCES TipoUniMed(CodTipoMed)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Salas disponveis para andares.
-- ------------------------------------------------------------

CREATE TABLE Sala (
  CodSala NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodAnd NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodSala),
  FOREIGN KEY(CodAnd)
    REFERENCES Andar(CodAnd)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodSala)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Equipamentos que realizam o aquecimento dos ovos.
-- ------------------------------------------------------------

CREATE TABLE Incubadora (
  CodEnc NUMERIC(3) NOT NULL DEFAULT nextval('incubadora_codenc'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodSala NUMERIC(12) NOT NULL,
  NomeEnc VARCHAR(100) NOT NULL,
  TPosEnc NUMERIC(2) NULL,
  DescEnc VARCHAR NULL,
  PRIMARY KEY(CodEnc),
  FOREIGN KEY(CodSala)
    REFERENCES Sala(CodSala)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Blocos em salas, possuem linhas em disposio.
-- ------------------------------------------------------------

CREATE TABLE Bloco (
  CodBloco NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodSala NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodBloco),
  FOREIGN KEY(CodSala)
    REFERENCES Sala(CodSala)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodBloco)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Equipamentos onde os ovos pemanecem na fase final de incubao.
-- ------------------------------------------------------------

CREATE TABLE Nascedouro (
  CodNes NUMERIC(3) NOT NULL DEFAULT nextval('nascedouro_codnes'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodSala NUMERIC(12) NOT NULL,
  NomeNes VARCHAR(100) NOT NULL,
  TColNes NUMERIC(2) NULL,
  DescNes VARCHAR NULL,
  PRIMARY KEY(CodNes),
  FOREIGN KEY(CodSala)
    REFERENCES Sala(CodSala)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Filas em blocos, possuem gaiolas em disposio.
-- ------------------------------------------------------------

CREATE TABLE Linha (
  CodLinha NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodBloco NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodLinha),
  FOREIGN KEY(CodBloco)
    REFERENCES Bloco(CodBloco)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodLinha)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Registro de posicionamento de bandeja em nascedouro.
-- ------------------------------------------------------------

CREATE TABLE PosBanNes (
  CodPosBanNes NUMERIC(10) NOT NULL DEFAULT nextval('posbannes_codposbannes'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodNes NUMERIC(3) NOT NULL,
  CodBan NUMERIC(8) NOT NULL,
  NPosNes NUMERIC(2) NOT NULL,
  DataAloNes TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  DataRetNes TIMESTAMP NULL,
  PRIMARY KEY(CodPosBanNes),
  FOREIGN KEY(CodNes)
    REFERENCES Nascedouro(CodNes)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodBan)
    REFERENCES Bandeja(CodBan)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Registro de posicionamento de bandeja em incubadora.
-- ------------------------------------------------------------

CREATE TABLE PosBanEnc (
  CodPosBanEnc NUMERIC(10) NOT NULL DEFAULT nextval('posbanenc_codposbanenc'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodEnc NUMERIC(3) NOT NULL,
  CodBan NUMERIC(8) NOT NULL,
  NPosEnc NUMERIC(2) NOT NULL,
  DataAloEnc TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  DataRetEnc TIMESTAMP NULL,
  PRIMARY KEY(CodPosBanEnc),
  FOREIGN KEY(CodEnc)
    REFERENCES Incubadora(CodEnc)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodBan)
    REFERENCES Bandeja(CodBan)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Posio de incubaes em bandejas de incubadoras.
-- ------------------------------------------------------------

CREATE TABLE IncTemEnt (
  CodInc NUMERIC(10) NOT NULL,
  CodEnt NUMERIC(12) NOT NULL,
  NLinBan NUMERIC(2) NOT NULL,
  NColBan NUMERIC(2) NOT NULL,
  CodPosBanEnc NUMERIC(10) NOT NULL,
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodMotDes NUMERIC(3) NOT NULL,
  OvoTransf CHAR(1) NULL,
  PRIMARY KEY(CodInc, CodEnt, NLinBan, NColBan, CodPosBanEnc),
  FOREIGN KEY(CodInc)
    REFERENCES Incubacao(CodInc)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodEnt)
    REFERENCES Entidade(CodEnt)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodPosBanEnc)
    REFERENCES PosBanEnc(CodPosBanEnc)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodMotDes)
    REFERENCES MotivoDescarte(CodMotDes)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Posio de nascimentos em bandejas de nascedouros.
-- ------------------------------------------------------------

CREATE TABLE NasTemEnt (
  CodEnt NUMERIC(12) NOT NULL,
  CodNas NUMERIC(10) NOT NULL,
  NLinBan NUMERIC(2) NOT NULL,
  NColBan NUMERIC(2) NOT NULL,
  CodPosBanNes NUMERIC(10) NOT NULL,
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodMotDes NUMERIC(3) NOT NULL,
  OvoNasceu CHAR(1) NULL,
  PRIMARY KEY(CodEnt, CodNas, NLinBan, NColBan, CodPosBanNes),
  FOREIGN KEY(CodNas)
    REFERENCES Nascimento(CodNas)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodEnt)
    REFERENCES Entidade(CodEnt)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(CodPosBanNes)
    REFERENCES PosBanNes(CodPosBanNes)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodMotDes)
    REFERENCES MotivoDescarte(CodMotDes)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Registra medidas de temperatura e umidade de mecanismo externo para incubadora.
-- ------------------------------------------------------------

CREATE TABLE HistIncubadora (
  CodHistEnc NUMERIC(20) NOT NULL DEFAULT nextval('histincubadora_codhistenc'),
  CodEnc NUMERIC(3) NOT NULL,
  DataMedEnc TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  TempMedEnc NUMERIC(6,4) NULL,
  UmiMedEnc NUMERIC(6,4) NULL,
  PRIMARY KEY(CodHistEnc),
  FOREIGN KEY(CodEnc)
    REFERENCES Incubadora(CodEnc)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
);

-- ------------------------------------------------------------
-- Registra medidas de temperatura e umidade de mecanismo externo para nascedouro
-- ------------------------------------------------------------

CREATE TABLE HistNascedouro (
  CodHistNes NUMERIC(20) NOT NULL DEFAULT nextval('histnascedouro_codhistnes'),
  CodNes NUMERIC(3) NOT NULL,
  DataMedNes TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  TempMedNes NUMERIC(6,4) NULL,
  UmiMedNes NUMERIC(6,4) NULL,
  PRIMARY KEY(CodHistNes),
  FOREIGN KEY(CodNes)
    REFERENCES Nascedouro(CodNes)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION
);

-- ------------------------------------------------------------
-- Filas em gaiolas, possuem clulas em disposio.
-- ------------------------------------------------------------

CREATE TABLE Gaiola (
  CodGai NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodLinha NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodGai),
  FOREIGN KEY(CodLinha)
    REFERENCES Linha(CodLinha)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodGai)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Clulas em gaiolas, possuem famlias de aves em um determinado momento.
-- ------------------------------------------------------------

CREATE TABLE Celula (
  CodCel NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodGai NUMERIC(12) NOT NULL,
  PRIMARY KEY(CodCel),
  FOREIGN KEY(CodGai)
    REFERENCES Gaiola(CodGai)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodCel)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Ovos produzidos por aves de famlias em clulas podem ser incubados.
-- ------------------------------------------------------------

CREATE TABLE Ovo (
  CodOvo NUMERIC(12) NOT NULL DEFAULT currval('entidade_codent'),
  CodBarras NUMERIC NULL,
  CodDesOvo NUMERIC(3) NOT NULL,
  CodStatusOvo NUMERIC(3) NOT NULL,
  CodForOvo NUMERIC(3) NOT NULL,
  CodCorOvo NUMERIC(3) NOT NULL,
  CodCel NUMERIC(12) NOT NULL,
  AquisOvo NUMERIC(12) NOT NULL,
  DataColOvo DATE NULL DEFAULT CURRENT_DATE,
  AspOvo VARCHAR(50) NULL,
  PesoOvo NUMERIC(6) NULL,
  PorOvo NUMERIC(14) NULL,
  Incubavel CHAR(1) NULL,
  PRIMARY KEY(CodOvo),
  FOREIGN KEY(CodStatusOvo)
    REFERENCES StatusOvo(CodStatusOvo)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodOvo)
    REFERENCES Entidade(CodEnt)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodForOvo)
    REFERENCES ForOvo(CodForOvo)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodCel)
    REFERENCES Celula(CodCel)
      ON DELETE NO ACTION
      ON UPDATE CASCADE,
  FOREIGN KEY(CodCorOvo)
    REFERENCES CorOvo(CodCorOvo)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodDesOvo)
    REFERENCES DesOvo(CodDesOvo)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(AquisOvo)
    REFERENCES Propriedade(CodProp)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Famlia composta por aves em uma clula.
-- ------------------------------------------------------------

CREATE TABLE Familia (
  CodFam NUMERIC(10) NOT NULL DEFAULT nextval('familia_codfam'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodCel NUMERIC(12) NOT NULL,
  NomeFam VARCHAR(50) NOT NULL,
  NumMacho NUMERIC(1) NULL,
  NumFemea NUMERIC(1) NULL,
  DataIniFam DATE NOT NULL,
  DataFimFam DATE NULL,
  PRIMARY KEY(CodFam),
  FOREIGN KEY(CodCel)
    REFERENCES Celula(CodCel)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);

-- ------------------------------------------------------------
-- Aves compe famlia em clulas e geram ovos por famlias.
-- ------------------------------------------------------------

CREATE TABLE Ave (
  CodAve NUMERIC(10) NOT NULL DEFAULT nextval('ave_codave'),
  CodStatusGeral NUMERIC(3) NOT NULL,
  CodMotMor NUMERIC(3) NOT NULL,
  CodOvo NUMERIC(12) NOT NULL,
  CodGS NUMERIC(3) NOT NULL,
  CodRaca NUMERIC(8) NOT NULL,
  CodFam NUMERIC(10) NOT NULL,
  SexoAve CHAR(1) NOT NULL,
  DataNasAve DATE NULL DEFAULT CURRENT_DATE,
  DataMorAve DATE NULL,
  MotMorAve VARCHAR NULL,
  PRIMARY KEY(CodAve),
  FOREIGN KEY(CodFam)
    REFERENCES Familia(CodFam)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  FOREIGN KEY(CodRaca)
    REFERENCES RacaAve(CodRaca)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodGS)
    REFERENCES GrauSangue(CodGS)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodOvo)
    REFERENCES Ovo(CodOvo)
      ON DELETE NO ACTION
      ON UPDATE NO ACTION,
  FOREIGN KEY(CodMotMor)
    REFERENCES MotivoMorte(CodMotMor)
      ON DELETE RESTRICT
      ON UPDATE CASCADE,
  FOREIGN KEY(CodStatusGeral)
    REFERENCES StatusGeral(CodStatusGeral)
      ON DELETE RESTRICT
      ON UPDATE CASCADE
);


